@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * SPDX-FileCopyrightText: 2020-2025 by Maik Qualmann <metzpinguin at gmail dot com>
- * SPDX-FileCopyrightText: 2002-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2026 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2009      by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
@@ -183,7 +183,7 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* view, const QDropEvent* e
 
         if (albumModel() && !(albumModel()->currentAlbums().isEmpty()))
         {
-            currentAlbum = albumModel()->currentAlbums().first();
+            currentAlbum = albumModel()->currentAlbums().constFirst();
         }
 
         if      (album->type() == Album::PHYSICAL)
