@@ -7,7 +7,7 @@
  * Description : Mysql internal database server
  *
  * SPDX-FileCopyrightText: 2009-2011 by Holger Foerster <Hamsi2k at freenet dot de>
- * SPDX-FileCopyrightText: 2010-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2026 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2016      by Swati Lodha <swatilodha27 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -40,6 +40,7 @@
 
 #include "digikam_debug.h"
 #include "digikam_globals.h"
+#include "actionthreadbase.h"
 
 namespace Digikam
 {
@@ -113,6 +114,8 @@ DatabaseServer::~DatabaseServer()
 
 void DatabaseServer::run()
 {
+    ActionThreadBase::setCurrentThreadName(QLatin1String("DatabaseServer"));       // To customize thread name
+
     quint64 runningTime = 0;
     int debugTime       = 0;
     int waitTime        = 1;
