@@ -4,7 +4,7 @@
  * Description : a tool to fix automatically camera lens aberrations
  *
  * SPDX-FileCopyrightText: 2008      by Adrian Schroeter <adrian at suse dot de>
- * SPDX-FileCopyrightText: 2008-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2026 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -558,7 +558,7 @@ LensFunIface::MetadataMatch LensFunIface::findFromMetadata(const DMetadata* cons
 
                 if (similar)
                 {
-                    qCDebug(DIGIKAM_DIMG_LOG) << "found similary match from" << lensMatches.count()
+                    qCDebug(DIGIKAM_DIMG_LOG) << "found similar match from" << lensMatches.count()
                                               << "possibilities:" << similar->Model
                                               << "similarity:" << percent;
                     setUsedLens(similar);
