@@ -7,7 +7,7 @@
  * Description : Widget to choose options for face scanning
  *
  * SPDX-FileCopyrightText: 2010-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2012-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2026 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2024-2025 by Michael Miller <michael underscore miller at msn dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -53,11 +53,9 @@ private:
 
 private Q_SLOTS:
 
+    void slotSettingsChanged();
     void slotPrepareForDetect(bool status);
     void slotPrepareForRecognize(bool status);
-    void slotDetectAccuracyChanged();
-    void slotDetectSizeChanged();
-    void slotRecognizeAccuracyChanged();
 
 private:
 
