@@ -6,7 +6,7 @@
  * Date        : 2006-20-12
  * Description : a view to embed QtMultimedia media player.
  *
- * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2026 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -25,7 +25,6 @@
 #include <QToolButton>
 #include <QFileInfo>
 #include <QToolBar>
-#include <QAction>
 #include <QSlider>
 #include <QLabel>
 #include <QFrame>
@@ -99,13 +98,6 @@ protected:
                     {
                         mplayer->slotEscapePressed();
                     }
-                    else if (
-                             (mouseEvent->button() == Qt::RightButton) &&
-                             (event->type()        == QEvent::MouseButtonPress)
-                            )
-                    {
-                        mplayer->slotRotateVideo();
-                    }
 
                     return true;
                 }
@@ -172,6 +164,8 @@ public:
     QAction*             grabAction         = nullptr;
     QAction*             backAction         = nullptr;
     QAction*             forwAction         = nullptr;
+    QAction*             rotlAction         = nullptr;
+    QAction*             rotrAction         = nullptr;
 
     QToolButton*         rateButton         = nullptr;
 
@@ -179,6 +173,7 @@ public:
     QPushButton*         speaker            = nullptr;
 
     QToolBar*            toolBar            = nullptr;
+    QWidget*             osdView            = nullptr;
 
     DInfoInterface*      iface              = nullptr;
 
@@ -253,6 +248,15 @@ public:
         videoView->fitInView(videoItem, Qt::KeepAspectRatio);
         videoView->centerOn(videoItem);
         videoView->raise();
+
+        if (osdView)
+        {
+            osdView->resize(videoView->width(),
+                            videoView->height());
+            osdView->raise();
+        }
+
+        toolBar->raise();
     };
 
     int videoMediaOrientation() const
@@ -284,17 +288,29 @@ MediaPlayerView::MediaPlayerView(QWidget* const parent)
     const int spacing      = layoutSpacing();
 
     d->prevAction          = new QAction(QIcon::fromTheme(QLatin1String("go-previous")),
-                                         i18nc("go to previous image", "Back"),           this);
+                                         i18nc("go to previous image", "Back"),                    this);
+    d->prevAction->setObjectName(QLatin1String("back"));
     d->nextAction          = new QAction(QIcon::fromTheme(QLatin1String("go-next")),
-                                         i18nc("go to next image", "Forward"),            this);
+                                         i18nc("go to next image", "Forward"),                     this);
+    d->nextAction->setObjectName(QLatin1String("next"));
     d->backAction          = new QAction(QIcon::fromTheme(QLatin1String("media-seek-backward")),
-                                         i18nc("video frame backward", "Frame Backward"), this);
+                                         i18nc("video frame backward", "Frame Backward"),          this);
+    d->backAction->setObjectName(QLatin1String("back"));
     d->playAction          = new QAction(QIcon::fromTheme(QLatin1String("media-playback-start")),
-                                         i18nc("pause/play video", "Pause/Play"),         this);
+                                         i18nc("pause/play video", "Pause/Play"),                  this);
+    d->playAction->setObjectName(QLatin1String("play"));
     d->forwAction          = new QAction(QIcon::fromTheme(QLatin1String("media-seek-forward")),
-                                         i18nc("video frame forward", "Frame Forward"),   this);
+                                         i18nc("video frame forward", "Frame Forward"),            this);
+    d->forwAction->setObjectName(QLatin1String("forw"));
     d->grabAction          = new QAction(QIcon::fromTheme(QLatin1String("view-preview")),
-                                         i18nc("capture video frame", "Capture"),         this);
+                                         i18nc("capture video frame", "Capture"),                  this);
+    d->grabAction->setObjectName(QLatin1String("grab"));
+    d->rotlAction          = new QAction(QIcon::fromTheme(QLatin1String("object-rotate-left")),
+                                         i18nc("rotate video in counterclockwize", "Rotate Left"), this);
+    d->rotlAction->setObjectName(QLatin1String("rotl"));
+    d->rotrAction          = new QAction(QIcon::fromTheme(QLatin1String("object-rotate-right")),
+                                         i18nc("rotate video in clockwize", "Rotate Right"),       this);
+    d->rotrAction->setObjectName(QLatin1String("rotr"));
 
     d->rateButton          = new QToolButton(this);
     d->rateButton->setToolTip(i18nc("@info", "Change video playback rate"));
@@ -302,7 +318,8 @@ MediaPlayerView::MediaPlayerView(QWidget* const parent)
     d->rateButton->setPopupMode(QToolButton::InstantPopup);
     d->rateButton->setArrowType(Qt::NoArrow);
 
-    QMenu* const rateMenu         = new QMenu(this);
+    QMenu* const rateMenu         = new QMenu(i18n("Rate"), this);
+    rateMenu->setIcon(QIcon::fromTheme(QLatin1String("player-time")));
     QActionGroup* const rateGroup = new QActionGroup(this);
 
     QAction* const rate05         = rateGroup->addAction(i18nc("video play rate", "0.5x"));
@@ -360,7 +377,7 @@ MediaPlayerView::MediaPlayerView(QWidget* const parent)
 
     d->playerView = new QFrame(this);
     d->videoScene = new QGraphicsScene(this);
-    d->videoView  = new QGraphicsView(d->videoScene);
+    d->videoView  = new QGraphicsView(d->videoScene, d->playerView);
     d->videoView->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     d->videoView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     d->videoView->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
@@ -441,6 +458,8 @@ MediaPlayerView::MediaPlayerView(QWidget* const parent)
     d->toolBar->addAction(d->forwAction);
     d->toolBar->addWidget(d->rateButton);
     d->toolBar->addAction(d->grabAction);
+    d->toolBar->addAction(d->rotlAction);
+    d->toolBar->addAction(d->rotrAction);
     d->toolBar->setStyleSheet(toolButtonStyleSheet());
 
     setPreviewMode(Private::PlayerView);
@@ -479,6 +498,12 @@ MediaPlayerView::MediaPlayerView(QWidget* const parent)
     connect(d->grabAction, SIGNAL(triggered()),
             this, SLOT(slotCapture()));
 
+    connect(d->rotlAction, SIGNAL(triggered()),
+            this, SLOT(slotRotateVideoLeft()));
+
+    connect(d->rotrAction, SIGNAL(triggered()),
+            this, SLOT(slotRotateVideoRight()));
+
     connect(d->slider, SIGNAL(sliderMoved(int)),
             this, SLOT(slotPosition(int)));
 
@@ -509,6 +534,9 @@ MediaPlayerView::MediaPlayerView(QWidget* const parent)
     connect(d->videoItem, SIGNAL(nativeSizeChanged(QSizeF)),
             this, SLOT(slotNativeSizeChanged()));
 
+    connect(d->player, SIGNAL(metaDataChanged()),
+            this, SLOT(slotMetaDataChanged()));
+
     connect(rateMenu, SIGNAL(triggered(QAction*)),
             this, SLOT(slotPlaybackRate(QAction*)));
 
@@ -524,6 +552,33 @@ MediaPlayerView::~MediaPlayerView()
     delete d;
 }
 
+QList<QAction*> MediaPlayerView::actionsList() const
+{
+    return QList<QAction*>() << d->prevAction
+                             << d->nextAction
+                             << d->playAction
+                             << d->forwAction
+                             << d->grabAction
+                             << d->rotlAction
+                             << d->rotrAction
+                             << d->rateButton->menu()->menuAction();
+}
+
+void MediaPlayerView::setToolbarVisible(bool b)
+{
+    d->toolBar->setVisible(b);
+}
+
+void MediaPlayerView::setToolbarExtraWidget(QWidget* const extra)
+{
+    d->toolBar->addWidget(extra);
+}
+
+void MediaPlayerView::setOsdWidget(QWidget* const osd)
+{
+    d->osdView = osd;
+}
+
 void MediaPlayerView::setInfoInterface(DInfoInterface* const iface)
 {
     d->iface = iface;
@@ -569,36 +624,43 @@ void MediaPlayerView::slotPlayerStateChanged(QMediaPlayer::PlaybackState newStat
 
 void MediaPlayerView::slotMediaStatusChanged(QMediaPlayer::MediaStatus newStatus)
 {
-    if      (newStatus == QMediaPlayer::LoadedMedia)
-    {
-        int rotate = d->videoMediaOrientation();
-
-        qCDebug(DIGIKAM_GENERAL_LOG) << "Found video orientation with QtMultimedia:"
-                                     << rotate;
-
-        rotate     = (-rotate) + d->videoOrientation;
-
-        if      (rotate > 270)
-        {
-            rotate = 0;
-        }
-        else if (rotate < 0)
-        {
-            rotate = 270;
-        }
-
-        d->setVideoItemOrientation(rotate);
-    }
-    else if (newStatus == QMediaPlayer::InvalidMedia)
+    if (newStatus == QMediaPlayer::InvalidMedia)
     {
         setPreviewMode(Private::ErrorView);
     }
 }
 
-void MediaPlayerView::escapePreview()
+void MediaPlayerView::slotHandlePlayerError(QMediaPlayer::Error /*error*/, const QString& errStr)
 {
-    d->player->stop();
-    d->player->setSource(d->dummyVideo);
+    setPreviewMode(Private::ErrorView);
+
+    qCDebug(DIGIKAM_GENERAL_LOG) << "QtMultimedia Error: " << errStr;
+}
+
+void MediaPlayerView::slotNativeSizeChanged()
+{
+    d->adjustVideoSize();
+}
+
+void MediaPlayerView::slotMetaDataChanged()
+{
+    int rotate = d->videoMediaOrientation();
+
+    qCDebug(DIGIKAM_GENERAL_LOG) << "Found video orientation with QtMultimedia:"
+                                 << rotate;
+
+    rotate     = (-rotate) + d->videoOrientation;
+
+    if      (rotate > 270)
+    {
+        rotate = 0;
+    }
+    else if (rotate < 0)
+    {
+        rotate = 270;
+    }
+
+    d->setVideoItemOrientation(rotate);
 }
 
 void MediaPlayerView::slotThemeChanged()
@@ -612,12 +674,55 @@ void MediaPlayerView::slotThemeChanged()
     d->playerView->setPalette(palette2);
 }
 
+void MediaPlayerView::escapePreview()
+{
+    d->player->stop();
+    d->player->setSource(d->dummyVideo);
+}
+
 void MediaPlayerView::slotEscapePressed()
 {
     Q_EMIT signalEscapePreview();
 }
 
-void MediaPlayerView::slotRotateVideo()
+void MediaPlayerView::slotRotateVideoLeft()
+{
+    if (d->player->playbackState() != QMediaPlayer::StoppedState)
+    {
+        int orientation = 0;
+
+        switch (d->videoOrientation)
+        {
+            case 0:
+            {
+                orientation = 270;
+                break;
+            }
+
+            case 90:
+            {
+                orientation = 0;
+                break;
+            }
+
+            case 180:
+            {
+                orientation = 90;
+                break;
+            }
+
+            default:
+            {
+                orientation = 180;
+                break;
+            }
+        }
+
+        d->setVideoItemOrientation(orientation);
+    }
+}
+
+void MediaPlayerView::slotRotateVideoRight()
 {
     if (d->player->playbackState() != QMediaPlayer::StoppedState)
     {
@@ -983,18 +1088,6 @@ void MediaPlayerView::slotPosition(int position)
     }
 }
 
-void MediaPlayerView::slotHandlePlayerError(QMediaPlayer::Error /*error*/, const QString& errStr)
-{
-    setPreviewMode(Private::ErrorView);
-
-    qCDebug(DIGIKAM_GENERAL_LOG) << "QtMultimedia Error: " << errStr;
-}
-
-void MediaPlayerView::slotNativeSizeChanged()
-{
-    d->adjustVideoSize();
-}
-
 bool MediaPlayerView::eventFilter(QObject* watched, QEvent* event)
 {
     if ((watched == d->playerView) && (event->type() == QEvent::Resize))
