@@ -7,7 +7,7 @@
  * Description : User interface for searches
  *
  * SPDX-FileCopyrightText: 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2011-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2026 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -361,7 +361,11 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
         {
             QString shortName = make[i];
             ItemPropertiesTab::shortenedMakeInfo(shortName);
-            makeMap.insert(shortName, wildcard.arg(shortName));
+
+            if (!shortName.isEmpty())
+            {
+                makeMap.insert(shortName, wildcard.arg(shortName));
+            }
         }
 
         make.clear();
@@ -392,7 +396,11 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
         {
             QString shortName = model[i];
             ItemPropertiesTab::shortenedModelInfo(shortName);
-            modelMap.insert(shortName, wildcard.arg(model[i]));
+
+            if (!shortName.isEmpty())
+            {
+                modelMap.insert(shortName, wildcard.arg(model[i]));
+            }
         }
 
         model.clear();
@@ -421,6 +429,23 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
 
         return field;
     }
+    else if (name == QLatin1String("nocamera"))
+    {
+        // choice
+
+        SearchFieldChoice* const field = new SearchFieldChoice(parent);
+        field->setFieldName(name);
+        field->setText(i18n("Camera"), i18n("Return items without a camera ..."));
+
+        QStringList noCamera;
+        noCamera << QLatin1String("make")  << i18nc("Camera", "Make")
+                 << QLatin1String("model") << i18nc("Camera", "Model")
+                 << QLatin1String("lens")  << i18nc("Camera", "Lens Type");
+
+        field->setChoice(noCamera);
+
+        return field;
+    }
     else if (name == QLatin1String("aperture"))
     {
         // double
@@ -1007,7 +1032,7 @@ SearchField* SearchField::createField(const QString& name, SearchFieldGroup* con
         type << QLatin1String("mp3")                << QLatin1String("MP3 (MPEG audio layer 3)");
         type << QLatin1String("mp3adu")             << QLatin1String("ADU (Application Data Unit) MP3 (MPEG audio layer 3)");
         type << QLatin1String("mp3on4")             << QLatin1String("MP3 on MP4");
-        type << QLatin1String("mp4als")             << QLatin1String("MPEG-4 Audio Lossless Coding (ALS)");
+        type << QLatin1String("mp4als")             << QLatin1String("MPEG-4 Audio Lossless Coding (ALS)");     // codespell:ignore als
         type << QLatin1String("musepack7")          << QLatin1String("Musepack SV7");
         type << QLatin1String("musepack8")          << QLatin1String("Musepack SV8");
         type << QLatin1String("nellymoser")         << QLatin1String("Nellymoser Asao");
