@@ -7,7 +7,7 @@
  * Description : album view configuration setup tab
  *
  * SPDX-FileCopyrightText: 2003-2004 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2005-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2026 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -42,9 +42,12 @@
 #include "thumbnailsize.h"
 #include "applicationsettings.h"
 #include "dfontselect.h"
+#include "dexpanderbox.h"
 #include "fullscreensettings.h"
 #include "dxmlguiwindow.h"
 #include "previewsettings.h"
+#include "previewosdsettings.h"
+#include "previewosdwidget.h"
 #include "setupcategory.h"
 #include "setupmime.h"
 
@@ -86,6 +89,7 @@ public:
     QCheckBox*          previewSmoothScaled             = nullptr;
     QCheckBox*          previewShowIcons                = nullptr;
     QCheckBox*          previewAutoPlay                 = nullptr;
+    QCheckBox*          previewOverlay                  = nullptr;
     QCheckBox*          showFolderTreeViewItemsCount    = nullptr;
     QCheckBox*          largeThumbsBox                  = nullptr;
 
@@ -100,6 +104,9 @@ public:
 
     FullScreenSettings* fullScreenSettings              = nullptr;
 
+    PreviewOsdSettings  osdSettings;
+    PreviewOsdWidget*   osdWidget                       = nullptr;
+
     SetupCategory*      category                        = nullptr;
     SetupMime*          mimetype                        = nullptr;
 };
@@ -120,65 +127,70 @@ SetupAlbumView::SetupAlbumView(QWidget* const parent)
     QGridLayout* const grid    = new QGridLayout(iwpanel);
 
     d->iconShowNameBox         = new QCheckBox(i18n("Show file&name"), iwpanel);
-    d->iconShowNameBox->setWhatsThis(i18n("Set this option to show the filename below the image thumbnail."));
+    d->iconShowNameBox->setWhatsThis(i18n("Set this option to show the filename below the thumbnail."));
 
     d->iconShowSizeBox         = new QCheckBox(i18n("Show file si&ze"), iwpanel);
-    d->iconShowSizeBox->setWhatsThis(i18n("Set this option to show the file size below the image thumbnail."));
+    d->iconShowSizeBox->setWhatsThis(i18n("Set this option to show the file size below the thumbnail."));
 
     d->iconShowDateBox         = new QCheckBox(i18n("Show camera creation &date"), iwpanel);
     d->iconShowDateBox->setWhatsThis(i18n("Set this option to show the camera creation date "
-                                          "below the image thumbnail."));
+                                          "below the thumbnail."));
 
     d->iconShowModDateBox      = new QCheckBox(i18n("Show file &modification date"), iwpanel);
     d->iconShowModDateBox->setWhatsThis(i18n("Set this option to show the file modification date "
-                                             "below the image thumbnail if it is different than camera creation date. "
+                                             "below the thumbnail if it is different than camera creation date. "
                                              "This option is useful to identify quickly which items have been modified."));
 
-    d->iconShowResolutionBox   = new QCheckBox(i18n("Show ima&ge dimensions"), iwpanel);
-    d->iconShowResolutionBox->setWhatsThis(i18n("Set this option to show the image size in pixels "
-                                                "below the image thumbnail."));
+    d->iconShowResolutionBox   = new QCheckBox(i18n("Show item dimensions"), iwpanel);
+    d->iconShowResolutionBox->setWhatsThis(i18n("Set this option to show the item size in pixels "
+                                                "below the thumbnail."));
 
-    d->iconShowAspectRatioBox  = new QCheckBox(i18n("Show image aspect ratio"), iwpanel);
-    d->iconShowAspectRatioBox->setWhatsThis(i18n("Set this option to show the image aspect ratio "
-                                                "below the image thumbnail."));
+    d->iconShowAspectRatioBox  = new QCheckBox(i18n("Show item aspect ratio"), iwpanel);
+    d->iconShowAspectRatioBox->setWhatsThis(i18n("Set this option to show the item aspect ratio "
+                                                "below the thumbnail."));
 
-    d->iconShowFormatBox       = new QCheckBox(i18n("Show image format"), iwpanel);
-    d->iconShowFormatBox->setWhatsThis(i18n("Set this option to show image mime type over image thumbnail."));
+    d->iconShowFormatBox       = new QCheckBox(i18n("Show item format"), iwpanel);
+    d->iconShowFormatBox->setWhatsThis(i18n("Set this option to show item mime type over thumbnail."));
 
     d->iconShowTitleBox        = new QCheckBox(i18n("Show digiKam tit&le"), iwpanel);
     d->iconShowTitleBox->setWhatsThis(i18n("Set this option to show the digiKam title "
-                                           "below the image thumbnail."));
+                                           "below the thumbnail."));
 
     d->iconShowCommentsBox     = new QCheckBox(i18n("Show digiKam &captions"), iwpanel);
     d->iconShowCommentsBox->setWhatsThis(i18n("Set this option to show the digiKam captions "
-                                              "below the image thumbnail."));
+                                              "below the thumbnail."));
 
     d->iconShowTagsBox         = new QCheckBox(i18n("Show digiKam &tags"), iwpanel);
     d->iconShowTagsBox->setWhatsThis(i18n("Set this option to show the digiKam tags list "
-                                          "below the image thumbnail."));
+                                          "below the thumbnail."));
 
     d->iconShowRatingBox       = new QCheckBox(i18n("Show digiKam &rating"), iwpanel);
     d->iconShowRatingBox->setWhatsThis(i18n("Set this option to show the digiKam rating "
-                                            "below the image thumbnail."));
+                                            "below the thumbnail."));
 
     d->iconShowPickLabelBox    = new QCheckBox(i18n("Show digiKam &pick label"), iwpanel);
     d->iconShowPickLabelBox->setWhatsThis(i18n("Set this option to show the digiKam pick label "
-                                            "below the image thumbnail."));
+                                            "below the thumbnail."));
 
     d->iconShowColorLabelBox   = new QCheckBox(i18n("Show digiKam color &label"), iwpanel);
     d->iconShowColorLabelBox->setWhatsThis(i18n("Set this option to show the digiKam color label "
-                                            "as a border around the thumbnail."));
+                                                "as a line below the thumbnail."));
+
+    DLineWidget* const line    = new DLineWidget(Qt::Horizontal, iwpanel);
 
     d->iconShowOverlaysBox     = new QCheckBox(i18n("Show rotation overlay buttons"), iwpanel);
-    d->iconShowOverlaysBox->setWhatsThis(i18n("Set this option to show overlay buttons over "
-                                              "the image thumbnail to be able to process left or right image rotation."));
+    d->iconShowOverlaysBox->setWhatsThis(i18n("Set this option to show the transformation overlay buttons over "
+                                              "the thumbnail to process left or right rotation."));
 
     d->iconShowFullscreenBox   = new QCheckBox(i18n("Show fullscreen overlay button"), iwpanel);
     d->iconShowFullscreenBox->setWhatsThis(i18n("Set this option to show an overlay button over the "
-                                                "image thumbnail to open it in fullscreen mode."));
+                                                "thumbnail to open it in fullscreen mode."));
 
-    d->iconShowCoordinatesBox  = new QCheckBox(i18n("Show Geolocation Indicator"), iwpanel);
-    d->iconShowCoordinatesBox->setWhatsThis(i18n("Set this option to show an icon over the image thumbnail if item has geolocation information."));
+    d->iconShowCoordinatesBox  = new QCheckBox(i18n("Show geolocation overlay button"), iwpanel);
+    d->iconShowCoordinatesBox->setWhatsThis(i18n("Set this option to show an overlay button over the "
+                                                 "thumbnail to identify geolocated item and open the map tab."));
+
+    DLineWidget* const line2   = new DLineWidget(Qt::Horizontal, iwpanel);
 
     QLabel* leftClickLabel     = new QLabel(i18n("Thumbnail click action:"), iwpanel);
     d->leftClickActionComboBox = new QComboBox(iwpanel);
@@ -199,33 +211,36 @@ SetupAlbumView::SetupAlbumView(QWidget* const parent)
                                          "digiKam needs to be restarted to take effect, and Rebuild Thumbnails option from Maintenance tool "
                                          "needs to be processed over whole collections."));
 
-    grid->addWidget(d->iconShowNameBox,          0, 0, 1, 1);
-    grid->addWidget(d->iconShowSizeBox,          1, 0, 1, 1);
-    grid->addWidget(d->iconShowDateBox,          2, 0, 1, 1);
-    grid->addWidget(d->iconShowModDateBox,       3, 0, 1, 1);
-    grid->addWidget(d->iconShowResolutionBox,    4, 0, 1, 1);
-    grid->addWidget(d->iconShowAspectRatioBox,   5, 0, 1, 1);
-    grid->addWidget(d->iconShowFormatBox,        6, 0, 1, 1);
-    grid->addWidget(d->iconShowCoordinatesBox,   7, 0, 1, 1);
+    grid->addWidget(d->iconShowNameBox,          0,  0, 1, 1);
+    grid->addWidget(d->iconShowSizeBox,          1,  0, 1, 1);
+    grid->addWidget(d->iconShowDateBox,          2,  0, 1, 1);
+    grid->addWidget(d->iconShowModDateBox,       3,  0, 1, 1);
+    grid->addWidget(d->iconShowResolutionBox,    4,  0, 1, 1);
+    grid->addWidget(d->iconShowAspectRatioBox,   5,  0, 1, 1);
+    grid->addWidget(d->iconShowFormatBox,        6,  0, 1, 1);
 
-    grid->addWidget(d->iconShowTitleBox,         0, 1, 1, 1);
-    grid->addWidget(d->iconShowCommentsBox,      1, 1, 1, 1);
-    grid->addWidget(d->iconShowTagsBox,          2, 1, 1, 1);
-    grid->addWidget(d->iconShowRatingBox,        3, 1, 1, 1);
-    grid->addWidget(d->iconShowPickLabelBox,     4, 1, 1, 1);
-    grid->addWidget(d->iconShowColorLabelBox,    5, 1, 1, 1);
-    grid->addWidget(d->iconShowOverlaysBox,      6, 1, 1, 1);
-    grid->addWidget(d->iconShowFullscreenBox,    7, 1, 1, 1);
+    grid->addWidget(d->iconShowTitleBox,         0,  1, 1, 1);
+    grid->addWidget(d->iconShowCommentsBox,      1,  1, 1, 1);
+    grid->addWidget(d->iconShowTagsBox,          2,  1, 1, 1);
+    grid->addWidget(d->iconShowRatingBox,        3,  1, 1, 1);
+    grid->addWidget(d->iconShowPickLabelBox,     4,  1, 1, 1);
+    grid->addWidget(d->iconShowColorLabelBox,    5,  1, 1, 1);
 
-    grid->addWidget(leftClickLabel,              9, 0, 1, 1);
-    grid->addWidget(d->leftClickActionComboBox,  9, 1, 1, 1);
-    grid->addWidget(d->iconViewFontSelect,       10, 0, 1, 2);
-    grid->addWidget(d->largeThumbsBox,           11, 0, 1, 2);
+    grid->addWidget(line,                        7,  0, 1, 2);
+    grid->addWidget(d->iconShowCoordinatesBox,   8,  0, 1, 1);
+    grid->addWidget(d->iconShowFullscreenBox,    8,  1, 1, 1);
+    grid->addWidget(d->iconShowOverlaysBox,      9,  0, 1, 1);
+    grid->addWidget(line2,                       10, 0, 1, 2);
+
+    grid->addWidget(leftClickLabel,              11, 0, 1, 1);
+    grid->addWidget(d->leftClickActionComboBox,  11, 1, 1, 1);
+    grid->addWidget(d->iconViewFontSelect,       12, 0, 1, 2);
+    grid->addWidget(d->largeThumbsBox,           13, 0, 1, 2);
 
     grid->setRowMinimumHeight(8, 10); // vertical space
     grid->setContentsMargins(spacing, spacing, spacing, spacing);
     grid->setSpacing(spacing);
-    grid->setRowStretch(13, 13);
+    grid->setRowStretch(14, 10);
 
     d->tab->insertTab(IconView, iwpanel, i18nc("@title:tab", "Icons"));
 
@@ -295,19 +310,24 @@ SetupAlbumView::SetupAlbumView(QWidget* const parent)
                                      "Raw data in full size (high quality)"), PreviewSettings::RawPreviewFromRawFullSize);
 
     d->previewConvertToEightBit   = new QCheckBox(i18n("Preview image is converted to 8 bits for a faster viewing"), pwpanel);
-    d->previewConvertToEightBit->setWhatsThis(i18n("Uncheck this if you do not want to convert a 16 bits preview image to 8 bits."));
+    d->previewConvertToEightBit->setWhatsThis(i18n("Check this if you want to convert a 16 bits preview image to 8 bits."));
 
     d->previewScaleFitToWindow    = new QCheckBox(i18n("Preview image is always scaled to fit to window"), pwpanel);
-    d->previewScaleFitToWindow->setWhatsThis(i18n("Uncheck this if you do not want to scale small images to fit to window."));
+    d->previewScaleFitToWindow->setWhatsThis(i18n("Check this if you want to scale small images to fit to window."));
 
     d->previewSmoothScaled        = new QCheckBox(i18n("Preview image use Anti-aliasing to scale up"), pwpanel);
-    d->previewSmoothScaled->setWhatsThis(i18n("Uncheck this if you do not want use Anti-aliasing to scale up."));
+    d->previewSmoothScaled->setWhatsThis(i18n("Check this if you want to use Anti-aliasing to scale up."));
 
     d->previewShowIcons           = new QCheckBox(i18n("Show icons and text over preview"), pwpanel);
-    d->previewShowIcons->setWhatsThis(i18n("Uncheck this if you do not want to see icons and text in the image preview."));
+    d->previewShowIcons->setWhatsThis(i18n("Check this if you want to see icons and text in the image preview."));
 
-    d->previewAutoPlay           = new QCheckBox(i18n("Auto play of videos or animations"), pwpanel);
-    d->previewAutoPlay->setWhatsThis(i18n("Uncheck this if you do not want to auto play of videos or animations."));
+    d->previewAutoPlay            = new QCheckBox(i18n("Auto play of videos or animations"), pwpanel);
+    d->previewAutoPlay->setWhatsThis(i18n("Check this if you want to auto play the videos or animations."));
+
+    d->previewOverlay             = new QCheckBox(i18n("Show a text overlay over preview."), pwpanel);
+    d->previewOverlay->setWhatsThis(i18n("Check this if you want to show a canvas overlay with technical shot settings and properties."));
+
+    d->osdWidget                  = new PreviewOsdWidget(&d->osdSettings, pwpanel);
 
     grid3->setContentsMargins(spacing, spacing, spacing, spacing);
     grid3->setSpacing(spacing);
@@ -320,7 +340,9 @@ SetupAlbumView::SetupAlbumView(QWidget* const parent)
     grid3->addWidget(d->previewSmoothScaled,      5, 0, 1, 2);
     grid3->addWidget(d->previewShowIcons,         6, 0, 1, 2);
     grid3->addWidget(d->previewAutoPlay,          7, 0, 1, 2);
-    grid3->setRowStretch(8, 10);
+    grid3->addWidget(d->previewOverlay,           8, 0, 1, 2);
+    grid3->addWidget(d->osdWidget,                9, 0, 1, 2);
+    grid3->setRowStretch(10, 10);
 
     d->previewFastPreview->setChecked(true);
     d->previewRawMode->setCurrentIndex(0);
@@ -361,6 +383,9 @@ SetupAlbumView::SetupAlbumView(QWidget* const parent)
     connect(d->previewFullView, SIGNAL(toggled(bool)),
             d->previewRawMode, SLOT(setEnabled(bool)));
 
+    connect(d->previewOverlay, SIGNAL(toggled(bool)),
+            d->osdWidget, SLOT(setEnabled(bool)));
+
     connect(d->largeThumbsBox, SIGNAL(toggled(bool)),
             this, SLOT(slotUseLargeThumbsToggled(bool)));
 
@@ -420,12 +445,16 @@ void SetupAlbumView::applySettings()
     settings->setPreviewSettings(previewSettings);
 
     settings->setPreviewAutoPlay(d->previewAutoPlay->isChecked());
+    settings->setPreviewOverlay(d->previewOverlay->isChecked());
     settings->setPreviewShowIcons(d->previewShowIcons->isChecked());
     settings->setPreviewSmoothScaled(d->previewSmoothScaled->isChecked());
     settings->setScaleFitToWindow(d->previewScaleFitToWindow->isChecked());
     settings->setShowFolderTreeViewItemsCount(d->showFolderTreeViewItemsCount->isChecked());
     settings->saveSettings();
 
+    d->osdWidget->writeSettings();
+    d->osdSettings.writeToConfig(QLatin1String("Preview OSD Settings"));
+
     KConfigGroup group = KSharedConfig::openConfig()->group(settings->generalConfigGroupName());
     d->fullScreenSettings->saveSettings(group);
 
@@ -488,12 +517,16 @@ void SetupAlbumView::readSettings()
     d->previewRawMode->setCurrentIndex(d->previewRawMode->findData(previewSettings.rawLoading));
 
     d->previewAutoPlay->setChecked(settings->getPreviewAutoPlay());
+    d->previewOverlay->setChecked(settings->getPreviewOverlay());
     d->previewShowIcons->setChecked(settings->getPreviewShowIcons());
     d->previewSmoothScaled->setChecked(settings->getPreviewSmoothScaled());
     d->previewScaleFitToWindow->setChecked(settings->getScaleFitToWindow());
     d->previewConvertToEightBit->setChecked(previewSettings.convertToEightBit);
     d->showFolderTreeViewItemsCount->setChecked(settings->getShowFolderTreeViewItemsCount());
 
+    d->osdSettings.readFromConfig(QLatin1String("Preview OSD Settings"));
+    d->osdWidget->readSettings();
+
     KConfigGroup group = KSharedConfig::openConfig()->group(settings->generalConfigGroupName());
     d->fullScreenSettings->readSettings(group);
 
